@@ -16,6 +16,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 #include <gtk/gtk.h>
+#include <stdlib.h> //exit
+#include <locale.h>
 
 //--GPE libs
 #include "gpe/init.h"
@@ -82,6 +84,8 @@ int main (int argc, char ** argv){
   textdomain (PACKAGE);
   setlocale (LC_ALL, "");
 
+  gpe_prefs_init("sketchbook_v1");
+  
   app_init (argc, argv);
   gui_init ();
   gtk_main ();
@@ -99,6 +103,7 @@ void app_init(int argc, char ** argv){
 
 void app_quit(){
   prefs_save_settings();
+  gpe_prefs_exit();
   gtk_exit (0);
 }
 
@@ -165,7 +170,7 @@ void gui_init(){
   gtk_notebook_insert_page(notebook, sketchpad_ui, NULL, PAGE_SKETCHPAD);
   gtk_notebook_insert_page(notebook, prefs_ui,     NULL, PAGE_PREFERENCES);
 
-#ifdef DEBUG
+#ifdef DEBUG__
   {
     GtkWidget * w;
     w = gtk_window_new (GTK_WINDOW_TOPLEVEL);
