@@ -28,11 +28,11 @@
 #include <stdlib.h>   //system()
 
 #include "gpe/errorbox.h"
-#include "gpe/gpe-iconlist.h"
+#include "gpe/gpeiconlistview.h"
+#include "gpe/gpeiconlistitem.h"
 
 #include "selector.h"
 #include "selector-gui.h"
-#include "note.h"
 #include "files.h"
 #include "sketchpad.h"
 #include "gpe-sketchbook.h"
@@ -43,41 +43,63 @@
 
 Selector selector;
 
-GtkCList  * selector_clist; 
-GdkColor bg_color;//alternate color for list cells
-
 gint sketch_list_size;
 gint current_sketch;
 gboolean is_current_sketch_selected;
 
 int _direntry_selector(const struct dirent * direntry);
-void _clist_update_alternate_colors_from(GtkCList * clist, gint index);
 
 void selector_init(){
+  GtkListStore * store;
+  
+  store = gtk_list_store_new (NUM_ENTRIES,
+                              G_TYPE_STRING,//title
+                              G_TYPE_STRING,//note's url
+                              GDK_TYPE_PIXBUF,//thumbnail
+                              G_TYPE_OBJECT//GPEIconListItem
+                              );
+  selector.listmodel = GTK_TREE_MODEL(store);
+
+  selector.thumbnails_notloaded = TRUE;
+
   sketch_list_size = 0;
   current_sketch   = SKETCH_NEW;
+
 }//selector_init()
 
-void set_selector_clist(GtkCList * clist){
-  selector_clist = clist;
+void selector_add_note(gchar * title, gchar * url, GdkPixbuf * thumbnail){
+  GtkListStore * store;
+  GtkTreeIter iter;
+
+  store = GTK_LIST_STORE(selector.listmodel);
+  gtk_list_store_append (store, &iter);
+  gtk_list_store_set (store, &iter,
+                      ENTRY_TITLE,     title,
+                      ENTRY_URL,       url,
+                      ENTRY_THUMBNAIL, thumbnail,
+                      -1);
+  g_free(url);  //liststore take a copy
+  g_free(title);//liststore take a copy
+
+  //gpe-iconlist is not linked to the model, so update it
+  if(thumbnail){
+    GObject * item;
+    item = gpe_icon_list_view_add_item_pixbuf (GPE_ICON_LIST_VIEW(selector.iconlist),
+                                         NULL, //title
+                                         thumbnail,//icon
+                                         gtk_tree_iter_copy(&iter));//udata
+    gtk_list_store_set (store, &iter,
+                        ENTRY_ICONLISTITEM, item,
+                        -1);  
+  }
 }
+
 void window_selector_init(GtkWidget * window_selector){
   struct dirent ** direntries;
   int scandir_nb_entries;
   int scandir_errno;
-  GdkColormap * colormap;
 
-  //--alternate bg color for list items
-  colormap = gdk_colormap_get_system();
-  bg_color.red   = 65535;
-  bg_color.green = 65535;
-  bg_color.blue  = 40000;
-  gdk_colormap_alloc_color(colormap, &bg_color, FALSE, TRUE);
-
-  //--Clist init
-  gtk_clist_column_titles_hide(selector_clist);//no title (single column)
-
-  //--fill CList
+  //--fill the List
   scandir_nb_entries = scandir (sketchbook.save_dir, &direntries, _direntry_selector, alphasort);//FIXME: --> file.c
   scandir_errno = errno;
   if (scandir_nb_entries == -1){//scandir error
@@ -110,46 +132,63 @@ void window_selector_init(GtkWidget * window_selector){
   }
   /*else*/{ //if empty, added a dummy sketch so do it in any case
     gchar * fullpath_filename;
-    gchar * line_text[1];
-    int line;
+    gchar * title;
     int i;
-    
     for(i = 0; i < scandir_nb_entries; i++){
-      Note * note;
 
-      line_text[0] = make_label_from_filename(direntries[i]->d_name);
+      title = make_label_from_filename(direntries[i]->d_name);
       fullpath_filename = g_strdup_printf("%s%s", sketchbook.save_dir, direntries[i]->d_name);
+      selector_add_note(title, fullpath_filename, NULL /*thumbnail*/);
 
-      line = gtk_clist_append(selector_clist, line_text);
-      note = note_new();
-      note->fullpath_filename = fullpath_filename;
-
-      {//--update thumbnail
-        GdkPixbuf * pixbuf;
-        GdkPixbuf * pixbuf_scaled;
-        pixbuf = gdk_pixbuf_new_from_file(note->fullpath_filename, NULL); //GError **error
-        pixbuf_scaled = gdk_pixbuf_scale_simple (pixbuf, //FIXME: let iconlist do that!
-                                                 THUMBNAIL_SIZE, THUMBNAIL_SIZE,
-                                                 GDK_INTERP_BILINEAR);
-        gdk_pixbuf_unref(pixbuf);
-        note->thumbnail = pixbuf_scaled;
-      }
-      gpe_iconlist_add_item_pixbuf (GPE_ICONLIST(selector.iconlist),
-                                    NULL,//"Sketch",
-                                    note->thumbnail,//icon
-                                    note);//udata
-      gtk_clist_set_row_data_full(selector_clist, line, note, note_destroy);
-      //do NOT g_free(fullpath_filename) now! :)
-      if(i%2) gtk_clist_set_background(selector_clist, i, &bg_color);
       sketch_list_size++;
-
-      g_free(line_text[0]);
     }
 
     free(direntries);
   }//else
 }//window_selector_init()
-  
+
+void load_thumbnails(){
+  GtkTreeModel * model;
+  GtkTreeIter iter;
+  gboolean is_node;
+
+  gchar     * filename;
+  GdkPixbuf * pixbuf;
+  GdkPixbuf * thumbnail;
+  GObject   * item;
+ 
+
+  model = GTK_TREE_MODEL(selector.listmodel);
+
+  is_node = gtk_tree_model_get_iter_first(model, &iter);
+
+  while (is_node) {
+    gtk_tree_model_get(model, &iter, ENTRY_URL, &filename, -1);
+
+    /**/g_printerr("loading %s...", filename);
+
+    pixbuf    = gdk_pixbuf_new_from_file(filename, NULL); //GError **error
+    thumbnail = gdk_pixbuf_scale_simple (pixbuf, THUMBNAIL_SIZE, THUMBNAIL_SIZE,
+                                         GDK_INTERP_BILINEAR);
+    gdk_pixbuf_unref(pixbuf);
+    gtk_list_store_set (GTK_LIST_STORE(model), &iter, ENTRY_THUMBNAIL, thumbnail, -1);
+
+    item = gpe_icon_list_view_add_item_pixbuf (GPE_ICON_LIST_VIEW(selector.iconlist),
+                                         NULL, //title
+                                         thumbnail,//icon
+                                         gtk_tree_iter_copy(&iter));//udata
+    gtk_list_store_set (GTK_LIST_STORE(model), &iter, ENTRY_ICONLISTITEM, item, -1);  
+
+    while (gtk_events_pending ()) gtk_main_iteration ();
+
+    /**/g_printerr("done.\n");
+
+    is_node = gtk_tree_model_iter_next(model, &iter);
+  }
+
+  selector.thumbnails_notloaded = FALSE;
+}
+
 void selector_refresh_list(){}
 
 gchar * make_label_from_filename(const gchar * filename){
@@ -203,17 +242,38 @@ int _direntry_selector (const struct dirent * direntry){
 }
 
 void delete_current_sketch(){
-  Note * note;
   gboolean is_deleted = FALSE;
   
-  note = gtk_clist_get_row_data(selector_clist, current_sketch);
-  is_deleted = file_delete(note->fullpath_filename);
+  GtkTreeModel * model;
+  GtkTreeIter iter;
+  gboolean got_it;
+  GtkTreePath * path;
+  gchar * fullpath_filename;
+  
+  model = GTK_TREE_MODEL(selector.listmodel);
 
+  path = gtk_tree_path_new_from_indices (current_sketch, -1);
+
+  got_it = gtk_tree_model_get_iter(model, &iter, path);
+  gtk_tree_path_free(path);
+  if(!got_it) return;
+
+  gtk_tree_model_get(model, &iter,
+                     ENTRY_URL, &fullpath_filename,
+                     -1);
+  
+  //--Delete the selected sketch
+  is_deleted = file_delete(fullpath_filename);
+  
   if(is_deleted){
-    gpe_iconlist_remove_item_with_udata(GPE_ICONLIST(selector.iconlist), note);
+    GObject * iconlist_item;
+    gtk_tree_model_get(model, &iter,
+                       ENTRY_ICONLISTITEM, &iconlist_item,
+                       -1);
 
-    _clist_update_alternate_colors_from(selector_clist, current_sketch);
-    gtk_clist_remove(selector_clist, current_sketch);
+    gpe_icon_list_view_remove_item(GPE_ICON_LIST_VIEW(selector.iconlist), iconlist_item);
+
+    gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
 
     if(is_current_sketch_last) current_sketch--;
     sketch_list_size--;
@@ -230,15 +290,21 @@ void delete_current_sketch(){
 }
 
 void open_indexed_sketch(gint index){
-  Note * note;
-  note = gtk_clist_get_row_data(selector_clist, index);
-  sketchpad_open_file(note->fullpath_filename);
-}
+  GtkTreeModel * model;
+  GtkTreeIter iter;
+  gboolean got_it;
+  GtkTreePath * path;
+  gchar * fullpath_filename;
+  
+  model = GTK_TREE_MODEL(selector.listmodel);
 
-void _clist_update_alternate_colors_from(GtkCList * clist, gint index){
-  gint i;
-  for(i = index; i < sketch_list_size; i++){
-    if(i%2) gtk_clist_set_background(clist, i, &white);
-    else    gtk_clist_set_background(clist, i, &bg_color);
-  }
+  path = gtk_tree_path_new_from_indices (index, -1);
+
+  got_it = gtk_tree_model_get_iter(model, &iter, path);
+  gtk_tree_path_free(path);
+  if(!got_it) return;
+
+  gtk_tree_model_get(model, &iter, ENTRY_URL, &fullpath_filename, -1);
+  sketchpad_open_file(fullpath_filename);
+  g_free(fullpath_filename);
 }
