@@ -24,13 +24,12 @@
 
 #include "gpe-sketchbook.h"
 #include "files.h"
-#include "note.h"
 #include "selector.h"
 #include "selector-cb.h"
 
 #include "dock.h"
 #include "gpe/question.h"
-#include "gpe/gpe-iconlist.h"
+#include "gpe/gpeiconlistview.h"
 #include "gpe/popup_menu.h"
 
 //--i18n
@@ -61,8 +60,12 @@ void on_window_size_allocate (GtkWidget     * widget,
   //**/           allocation->width, allocation->height);
 
   if(dock == NULL) return;
-
-  if(allocation->width > 260)//240)//FIXME: that's very ugly way to detect LANDSCAPE mode!
+  
+  /* Set vertical on small screens in landscape mode.
+     On large screens stay horizontal like in portrait mode to look
+     more like a common PC application. */
+    
+  if ((allocation->width > allocation->height+20) && (allocation->width <= 640))
     gpe_dock_change_toolbar_orientation((GpeDock *)dock, GTK_ORIENTATION_VERTICAL);
   else//Portrait mode
     gpe_dock_change_toolbar_orientation((GpeDock *)dock, GTK_ORIENTATION_HORIZONTAL); 
@@ -93,19 +96,24 @@ void on_button_list_view_clicked(GtkButton *button, gpointer user_data){
   if (_save_current_if_needed() == ACTION_CANCELED) return;
 
   if(is_current_sketch_new){
-    gtk_clist_unselect_all(selector_clist);
-    GTK_CLIST(selector_clist)->focus_row = -1;
+    gboolean ret;
+    g_signal_emit_by_name(G_OBJECT(selector.textlistview), "unselect-all", &ret);
     gtk_widget_set_sensitive(selector.button_edit,   FALSE);
     gtk_widget_set_sensitive(selector.button_delete, FALSE);
   }
   else{
+    GtkTreeSelection * selection;
+    GtkTreePath * path;
+
+    selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(selector.textlistview));
+    /**/g_printerr("Selecting %d\n", current_sketch);
+    path = gtk_tree_path_new_from_indices(current_sketch, -1);
+    gtk_tree_selection_select_path(selection, path);
+    gtk_tree_path_free(path);
+
     //set the current one selected
     set_current_sketch_selected();
-    gtk_clist_select_row(selector_clist, current_sketch, 1);
-    GTK_CLIST(selector_clist)->focus_row = current_sketch;
-    gtk_signal_emit_by_name((GtkObject *)selector_clist, "select-row",
-                            current_sketch, 1,
-                            NULL, NULL);//highlight the selected item
+
     gtk_widget_set_sensitive(selector.button_edit,   TRUE);
     gtk_widget_set_sensitive(selector.button_delete, TRUE);
   }
@@ -154,22 +162,35 @@ gint on_key_press(GtkWidget *widget, GdkEventKey *ev, gpointer data){
 //--------------------- FILE TOOLBAR ----------------------
 
 void on_button_file_save_clicked(GtkButton *button, gpointer unused){
-  Note * note;
+  gchar     * filename  = NULL;
+  GdkPixbuf * thumbnail = NULL;
+  GObject   * iconlist_item = NULL;
+  GtkTreeIter iter;
 
   if(!is_current_sketch_modified){
     popup_menu_close (sketchpad.files_popup_button);
     return;
   }
   if(is_current_sketch_new){
-    note = note_new();
-    note->fullpath_filename = file_new_fullpath_filename();
+    filename = file_new_fullpath_filename();
   }
   else{
-    note =  gtk_clist_get_row_data(selector_clist, current_sketch);
+    //access the existing row data
+    gchar * path_string;
+    path_string = g_strdup_printf("%d", current_sketch);
+
+    /*gboolean*/gtk_tree_model_get_iter_from_string( selector.listmodel, &iter, path_string);
+    g_free(path_string);
+    gtk_tree_model_get(selector.listmodel, &iter,
+                       ENTRY_URL, &filename,
+                       ENTRY_THUMBNAIL, &thumbnail,
+                       ENTRY_ICONLISTITEM, &iconlist_item,
+                       -1);
   }
 
-  file_save(note->fullpath_filename); //FIXME: should catch saving errors
-  {//--update thumbnail
+  file_save(filename); //FIXME: should catch saving errors
+  
+  if(selector.thumbnails_notloaded == FALSE){//--make thumbnail
     GdkPixbuf * pixbuf;
     GdkPixbuf * pixbuf_scaled;
     pixbuf = sketchpad_get_current_sketch_pixbuf();
@@ -177,30 +198,19 @@ void on_button_file_save_clicked(GtkButton *button, gpointer unused){
                                              THUMBNAIL_SIZE, THUMBNAIL_SIZE,
                                              GDK_INTERP_BILINEAR);
     gdk_pixbuf_unref(pixbuf);
-    if(note->thumbnail) gdk_pixbuf_unref(note->thumbnail);
-    note->thumbnail = pixbuf_scaled;
+    if(thumbnail) gdk_pixbuf_unref(thumbnail);
+    thumbnail = pixbuf_scaled;
   }
 
   if(is_current_sketch_new){
-    gchar * name[1];
-
+    current_sketch = sketch_list_size;
     sketch_list_size++;
 
-    name[0] = make_label_from_filename(note->fullpath_filename);
-    current_sketch = gtk_clist_append(selector_clist, name);
-    g_free(name[0]);
-    gtk_clist_set_row_data_full(selector_clist, current_sketch, note, note_destroy);
-    if(current_sketch%2) gtk_clist_set_background(selector_clist, current_sketch, &bg_color);
-
-    gpe_iconlist_add_item_pixbuf (GPE_ICONLIST(selector.iconlist),
-                                  NULL,// "Sketch"
-                                  note->thumbnail,
-                                  note);
+    selector_add_note(make_label_from_filename(filename), filename, thumbnail);
   }
-  else{
+  else if(selector.thumbnails_notloaded == FALSE){
     //update icon_view
-    gpe_iconlist_update_icon_item_with_udata (GPE_ICONLIST(selector.iconlist),
-                                              note->thumbnail, note);
+  	gpe_icon_list_view_set_item_icon(GPE_ICON_LIST_VIEW(selector.iconlist), iconlist_item, thumbnail);
   }
   is_current_sketch_modified = FALSE;
   sketchpad_reset_title();
@@ -395,4 +405,3 @@ on_drawing_area_button_release_event(GtkWidget       *widget,
   prev_pos_x = prev_pos_y = NO_PREV_POS;
   return FALSE;
 }
-
